#
# spec file for package falcosidekick
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           falcosidekick
Version:        2.31.1
Release:        1.2
Summary:        A simple daemon for connecting Falco to your ecosystem
License:        Apache-2.0
URL:            https://github.com/falcosecurity/falcosidekick
Source0:        %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
# taken from https://github.com/falcosecurity/falcosidekick?tab=readme-ov-file#with-systemd
Source2:        %{name}.service
BuildRequires:  go >= 1.23

%description
A simple daemon for connecting Falco to your ecosystem. It takes a Falco events
and forward them to different outputs in a fan-out way.

It works as a single endpoint for as many Falco instances as you want.

%prep
%autosetup -p 1 -a 1

%build
COMMIT_HASH="$(sed -n 's/commit: \(.*\)/\1/p' %_sourcedir/%{name}.obsinfo)"

DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X main.GitVersion=%{version} \
   -X main.gitCommit=${COMMIT_HASH} \
   -X main.gitTreeState=clean \
   -X main.buildDate=${BUILD_DATE}" \
   -o bin/%{name} .

%install
# Install the binary.
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

# systemd unit
install -D -m 0644 %{SOURCE2} %{buildroot}/%{_unitdir}/%{name}.service

# configuration directory
install -d -m 0755 %{buildroot}/%{_sysconfdir}/%{name}

%pre
%service_add_pre %{name}.service

%post
%service_add_post %{name}.service

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}
%{_unitdir}/%{name}.service
%dir %attr(770,root,root) %config %{_sysconfdir}/%{name}

%changelog
* Fri Feb  7 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.31.1:
  * prepare v2.31.1
  * Adding scope ScopeReadWrite for uploading file for GCS Bucket
  * build(deps): bump the actions group with 3 updates
  * build(deps): bump cloud.google.com/go/pubsub from 1.45.3 to
    1.47.0
* Fri Feb  7 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.31.0:
  * prepare v2.31.0
  * add new output OTLP Logs + improve the OTLP Traces/Metrics
  * fix typo
  * Update handlers to match stats_prometheus.go
  * fix custom headers not added to loki output http/s requests
  * fix Falcosidekick name for consistency
  * change the printer for the logs
  * allow to set the format for the value in Loki log lines
  * replace dots . by underscores . in Loki labels for consistency
  * add templated fields in Loki and Prometheus outputs
  * use a global method for the logs
  * fix the failing creation of the cluster policy report
  * allow to set a template for the nats/stan subjects
  * build(deps): bump go.opentelemetry.io/otel/sdk from 1.33.0 to
    1.34.0
  * build(deps): bump the gomod group with 2 updates
  * build(deps): bump golangci/golangci-lint-action in the actions
    group
  * :bug: Removed size allocation for the loki map
  * :art: Go fmt
  * :wrench: Add NS and pod by default in loki output
  * build(deps): bump docker/setup-qemu-action in the actions group
  * remove debug line -_-
  * build(deps): bump golang.org/x/oauth2 from 0.24.0 to 0.25.0
  * build(deps): bump google.golang.org/api from 0.211.0 to 0.214.0
  * build(deps): bump github.com/nats-io/nats.go from 1.37.0 to
    1.38.0
  * build(deps): bump go.opentelemetry.io/otel/sdk/metric
  * build(deps): bump the gomod group with 3 updates
  * build(deps): bump golang.org/x/crypto from 0.29.0 to 0.31.0
  * build(deps): bump the actions group with 3 updates
  * build(deps): bump golang.org/x/text from 0.20.0 to 0.21.0
  * build(deps): bump go.opentelemetry.io/otel/metric from 1.32.0
    to 1.33.0
  * build(deps): bump golang.org/x/sync from 0.9.0 to 0.10.0
  * build(deps): bump cloud.google.com/go/pubsub
  * build(deps): bump cloud.google.com/go/storage from 1.47.0 to
    1.48.0
  * remove the log line for OTLP Metrics (too noisy)
* Fri Nov 29 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.30.0:
  * New
  - New output: Webex (PR#979 thanks to @k0rventen)
  - New output: OTLP Metrics (PR#1012 thanks to @ekoops)
  - New output: Datadog Logs (PR#1052 thanks to @yohboy)
  * Enhancement
  - Reuse of the http client for 3-4x increase of the throughput
    (PR#962 thanks to @alekmaus)
  - Improve outputs throughput handling (PR#966 thanks to
    @alekmaus)
  - Batching and gzip compression for the Elastticsearch output
    (PR#967 thanks to @alekmaus)
  - Use the same convention for the Prometheus metrics than Falco
    (PR#995)
  - Add APIKey for Elasticsearch output (PR#980 thanks to
    @alekmaus)
  - Add Pipeline configuration for Elasticsearch output (PR#981
    thanks to @alekmaus)
  - Add MessageThreadID configuration in Telegram output (PR#1008
    thanks to @vashian)
  - Support multi-architecture in build (PR#1024 thanks to
    @nickytd)
  - Add falco as source for the Datadog Events (PR#1043 thanks to
    @maxd-wttj)
  - Support AlertManager output in HA mode (PR#1051)
  * Fix
  - Fix PolicyReports created in the same namespace than previous
    event (PR#978)
  - Fix missing customFields/extraFields in the Elasticsearch
    payload (PR#1033)
  - Fix incorrect key name for CloudEvent spec attribute
    (PR#1051)
  * Warning
  - Breaking change: The Prometheus metrics have different names
    from this release, it might break the queries for the
    dashboards and alerts.
* Wed Jul  3 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.29.0:
  * specify goreleaser version
  * Add ClientCAs to TLSServer configuration
  * Add Sumologic Output
  * Add custom TLS CA global option
  * Add test for utils sorting function
  * Added 'Install' section to systemd example in README
  * Apply suggestions from code review
  * CI: fix linting
  * Docs fix: Environment variables are all uppercase
  * Fix G402: TLS MinVersion too low
  * Fix Policy Report dead link
  * Fix condition for forwarding events to OTLP traces
  * Go fmt
  * Make S3 output compatible with non-AWS S3 API-compliant
    endpoints
  * Split docs for the outputs
  * Update README.md
  * Update README.md path to the correct one
  * Update config_example.yaml
  * Update docs/outputs/alertmanager.md
  * Update docs/outputs/syslog.md
  * Update outputs/client.go
  * Update outputs/otlp.go
  * Update release.yml
  * Update syslog.md
  * Update types/types.go
  * add Falco Talon output
  * add flattenfields + create indexte
  * add more checks for the upload on GCP Storage
  * add outputFieldFormat parameter
  * add screenshots from running whole OTLP stack (under
    docker-compose, as documented)
  * add source as label for prom metrics
  * add table of contents + fix missing link
  * address more @issif feedback (cleanup)
  * bump up go version to 1.21 + bump up alpine base image to 3.19
    + replace deprecated modules for azure
  * change the method to set the custom headers in the client.go,
    it allows now to override the content-type
  * chore: remove refs to deprecated io/ioutil
  * clarify the un-need to parse OTLP.Traces.Headers field
  * display error message according to standards
  * docs(LICENSE): add Apache 2.0
  * docs(README.md): remove leftover
  * docs(dynatrace): Fix typo in Dynatrace example image
  * docs(dynatrace): [TR-1498] Add checkcert key to example config
  * docs(dynatrace): [TR-1498] Add example image of Dynatrace
  * docs: add license headers and spdx id
  * docs: update SPDX-License-Identifier and cleanup copyright
    notices
  * feat(alertmanager): add custom headers to alert manager
  * feat(alertmanager): fix labels for alertmanager
  * feat(alertmanager): remove leading and tailing _
  * feat(alertmanager): replace __ with _ in alertmanger labels
  * feat(dynatrace): [TR-1498] Enhance Dynatrace output with
    semantic attributes
  * feat(dynatrace): [TR-1498] Implement Dynatrace output
  * feat(log_inlined_json): inline the json logs when it's possible
  * feat(quickwit_output): implement the quickwit output
  * feat: add OTLP/Traces output support
  * fix bug with extension 'source'
  * fix issue #780: duplicated headers
  * fix outputs/otlp_test.go for NewClient() using
    `types.InitClientArgs`
  * fix panic in prometheus when hostname field is missing
  * fix the docs for Dynatrace output
  * fix wrong env var for pagerduty output
  * fix(dynatrace): [TR-1706] Check for nil when parsing output
    fields and parse span.id
  * fix(dynatrace): [TR-1706] Correct Falco output name
    container.image, k8s.ns.name and Dynatrace field name
    k8s.pod.uid
  * fix(elasticsearch-doc): remove mattermost config coming from a
    cc/cl mistake
  * fix(loki): fix the deadlock in Loki integration
  * go mod tidy (using go1.20.13)
  * initialise root CAs for kafka output
  * prepare v2.29.0
  * refactor(dynatrace): [TR-1498] Remove redundant check for token
    existence
  * refactor(init_client): merge InitClient and NewClient functions
  * remove hard setting of the Mattermost Username
  * remove hard setting of the Rocketchat Username
  * remove nested functions
  * remove wrongly added local files
  * revamp the policy reporter output
  * set source to internal for the test rule
  * test(dynatrace): [TR-1706] Add unit tests for the Dynatrace
    output
  * truncate output fiels with a length > 512 chars, a payload >
    4096 is not accepted by a lot of outputs
  * try to use a consistent order for the output_fields and tags
    for more outputs
  * update all deps + fix issues coming with
  * update copyright year to 2024
  * update dependencies
  * update logs for TLS
  * update the installation section
  * use go 1.20 (fix CI), fix NewClient() call to use new
    `types.InitClientArgs`
* Wed May 15 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package falcosidekick: simple daemon for connecting Falco to
  your ecosystem
